# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['swarms',
 'swarms.agents',
 'swarms.cli',
 'swarms.memory',
 'swarms.models',
 'swarms.prompts',
 'swarms.structs',
 'swarms.telemetry',
 'swarms.tools',
 'swarms.utils',
 'swarms.workers']

package_data = \
{'': ['*']}

install_requires = \
['Pillow==9.4.0',
 'PyPDF2==3.0.1',
 'accelerate',
 'asyncio==3.4.3',
 'attrs==22.2.0',
 'backoff==2.2.1',
 'beautifulsoup4==4.11.2',
 'bitsandbytes',
 'black==23.3.0',
 'chromadb==0.4.14',
 'cohere==4.24',
 'datasets',
 'diffusers',
 'einops==0.7.0',
 'faiss-cpu==1.7.4',
 'ggl==1.1.0',
 'google-generativeai==0.3.1',
 'httpx==0.24.1',
 'huggingface-hub',
 'langchain-experimental==0.0.10',
 'langchain==0.0.333',
 'marshmallow==3.19.0',
 'modelscope==1.10.0',
 'open_clip_torch==2.20.0',
 'openai==0.28.0',
 'opencv-python-headless==4.8.1.78',
 'optimum==1.15.0',
 'peft',
 'pgvector',
 'playwright==1.34.0',
 'pydantic==1.10.12',
 'qdrant-client',
 'ratelimit==2.2.1',
 'rich==13.5.2',
 'safetensors==0.3.3',
 'sentence-transformers',
 'sentencepiece==0.1.98',
 'soundfile==0.12.1',
 'sqlalchemy',
 'tabulate==0.9.0',
 'tenacity==8.2.2',
 'tensorflow==2.14.0',
 'termcolor==2.2.0',
 'tiktoken==0.4.0',
 'torch==2.1.1',
 'torchvision==0.16.1',
 'transformers==4.36.2',
 'weaviate-client==3.25.3',
 'wget==3.2']

entry_points = \
{'console_scripts': ['swarms = swarms.cli._cli:cli']}

setup_kwargs = {
    'name': 'swarms',
    'version': '3.4.1',
    'description': 'Swarms - Pytorch',
    'long_description': '![Swarming banner icon](images/swarmslogobanner.png)\n\n<div align="center">\n\nSwarms is a modular framework that enables reliable and useful multi-agent collaboration at scale to automate real-world tasks.\n\n\n[![GitHub issues](https://img.shields.io/github/issues/kyegomez/swarms)](https://github.com/kyegomez/swarms/issues) [![GitHub forks](https://img.shields.io/github/forks/kyegomez/swarms)](https://github.com/kyegomez/swarms/network) [![GitHub stars](https://img.shields.io/github/stars/kyegomez/swarms)](https://github.com/kyegomez/swarms/stargazers) [![GitHub license](https://img.shields.io/github/license/kyegomez/swarms)](https://github.com/kyegomez/swarms/blob/main/LICENSE)[![GitHub star chart](https://img.shields.io/github/stars/kyegomez/swarms?style=social)](https://star-history.com/#kyegomez/swarms)[![Dependency Status](https://img.shields.io/librariesio/github/kyegomez/swarms)](https://libraries.io/github/kyegomez/swarms) [![Downloads](https://static.pepy.tech/badge/swarms/month)](https://pepy.tech/project/swarms)\n\n[![Join the Agora discord](https://img.shields.io/discord/1110910277110743103?label=Discord&logo=discord&logoColor=white&style=plastic&color=d7b023)![Share on Twitter](https://img.shields.io/twitter/url/https/twitter.com/cloudposse.svg?style=social&label=Share%20%40kyegomez/swarms)](https://twitter.com/intent/tweet?text=Check%20out%20this%20amazing%20AI%20project:%20&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms) [![Share on Facebook](https://img.shields.io/badge/Share-%20facebook-blue)](https://www.facebook.com/sharer/sharer.php?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms) [![Share on LinkedIn](https://img.shields.io/badge/Share-%20linkedin-blue)](https://www.linkedin.com/shareArticle?mini=true&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&title=&summary=&source=)\n\n[![Share on Reddit](https://img.shields.io/badge/-Share%20on%20Reddit-orange)](https://www.reddit.com/submit?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&title=Swarms%20-%20the%20future%20of%20AI) [![Share on Hacker News](https://img.shields.io/badge/-Share%20on%20Hacker%20News-orange)](https://news.ycombinator.com/submitlink?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&t=Swarms%20-%20the%20future%20of%20AI) [![Share on Pinterest](https://img.shields.io/badge/-Share%20on%20Pinterest-red)](https://pinterest.com/pin/create/button/?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&media=https%3A%2F%2Fexample.com%2Fimage.jpg&description=Swarms%20-%20the%20future%20of%20AI) [![Share on WhatsApp](https://img.shields.io/badge/-Share%20on%20WhatsApp-green)](https://api.whatsapp.com/send?text=Check%20out%20Swarms%20-%20the%20future%20of%20AI%20%23swarms%20%23AI%0A%0Ahttps%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\n</div>\n\n\n----\n\n## Installation\n`pip3 install --upgrade swarms`\n\n---\n\n## Usage\n\nRun example in Collab: <a target="_blank" href="https://colab.research.google.com/github/kyegomez/swarms/blob/master/playground/swarms_example.ipynb">\n<img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/>\n</a>\n\n### `Agent`\n- Reliable Structure that provides LLMS autonomy\n- Extremely Customizeable with stopping conditions, interactivity, dynamical temperature, loop intervals, and so much more\n- Enterprise Grade + Production Grade: `Agent` is designed and optimized for automating real-world tasks at scale!\n\n```python\nimport os\n\nfrom dotenv import load_dotenv\n\n# Import the OpenAIChat model and the Agent struct\nfrom swarms.models import OpenAIChat\nfrom swarms.structs import Agent\n\n# Load the environment variables\nload_dotenv()\n\n# Get the API key from the environment\napi_key = os.environ.get("OPENAI_API_KEY")\n\n# Initialize the language model\nllm = OpenAIChat(\n    temperature=0.5,\n    model_name="gpt-4",\n    openai_api_key=api_key,\n    max_tokens=4000\n)\n\n\n## Initialize the workflow\nagent = Agent(llm=llm, max_loops=1, autosave=True, dashboard=True)\n\n# Run the workflow on a task\nagent.run("Generate a 10,000 word blog on health and wellness.")\n\n\n\n```\n\n\n### `ToolAgent`\n\n- Versatility: The ToolAgent class is designed to be flexible and adaptable. It can be used with any model and tokenizer, making it suitable for a wide range of tasks. This versatility means that you can use ToolAgent as a foundation for any tool that requires language model processing.\n\n- Ease of Use: With its simple and intuitive interface, ToolAgent makes it easy to perform complex tasks. Just initialize it with your model, tokenizer, and JSON schema, and then call the run method with your task. This ease of use allows you to focus on your task, not on setting up your tools.\n\n- Customizability: ToolAgent accepts variable length arguments and keyword arguments, allowing you to customize its behavior to suit your needs. Whether you need to adjust the temperature of the model\'s output, limit the number of tokens, or tweak any other parameter, ToolAgent has you covered. This customizability ensures that ToolAgent can adapt to your specific requirements.\n\n\n```python\nfrom transformers import AutoModelForCausalLM, AutoTokenizer\nfrom swarms import ToolAgent\n\n\nmodel = AutoModelForCausalLM.from_pretrained("databricks/dolly-v2-12b")\ntokenizer = AutoTokenizer.from_pretrained("databricks/dolly-v2-12b")\n\njson_schema = {\n    "type": "object",\n    "properties": {\n        "name": {"type": "string"},\n        "age": {"type": "number"},\n        "is_student": {"type": "boolean"},\n        "courses": {\n            "type": "array",\n            "items": {"type": "string"}\n        }\n    }\n}\n\ntask = "Generate a person\'s information based on the following schema:"\nagent = ToolAgent(model=model, tokenizer=tokenizer, json_schema=json_schema)\ngenerated_data = agent.run(task)\n\nprint(generated_data)\n\n```\n\n------\n\n### `SequentialWorkflow`\n- A Sequential swarm of autonomous agents where each agent\'s outputs are fed into the next agent\n- Save and Restore Workflow states!\n- Integrate Agent\'s with various LLMs and Multi-Modality Models\n\n```python\nimport os \nfrom swarms.models import OpenAIChat\nfrom swarms.structs import Agent\nfrom swarms.structs.sequential_workflow import SequentialWorkflow\nfrom dotenv import load_dotenv\n\nload_dotenv()\n\n# Load the environment variables\napi_key = os.getenv("OPENAI_API_KEY")\n\n\n# Initialize the language agent\nllm = OpenAIChat(\n    temperature=0.5,\n    model_name="gpt-4",\n    openai_api_key=api_key,\n    max_tokens=4000\n)\n\n\n# Initialize the agent with the language agent\nagent1 = Agent(llm=llm, max_loops=1)\n\n# Create another agent for a different task\nagent2 = Agent(llm=llm, max_loops=1)\n\n# Create another agent for a different task\nagent3 = Agent(llm=llm, max_loops=1)\n\n# Create the workflow\nworkflow = SequentialWorkflow(max_loops=1)\n\n# Add tasks to the workflow\nworkflow.add(\n    agent1, "Generate a 10,000 word blog on health and wellness.", \n)\n\n# Suppose the next task takes the output of the first task as input\nworkflow.add(\n    agent2, "Summarize the generated blog",\n)\n\n# Run the workflow\nworkflow.run()\n\n# Output the results\nfor task in workflow.tasks:\n    print(f"Task: {task.description}, Result: {task.result}")\n```\n\n\n\n### `ConcurrentWorkflow`\n- Run all the tasks all at the same time\n```python\nimport os \nfrom dotenv import load_dotenv \nfrom swarms import OpenAIChat, Task, ConcurrentWorkflow, Agent\n\n# Load environment variables from .env file\nload_dotenv()\n\n# Load environment variables\nllm = OpenAIChat(openai_api_key=os.getenv("OPENAI_API_KEY"))\nagent = Agent(llm=llm, max_loops=1)\n\n# Create a workflow\nworkflow = ConcurrentWorkflow(max_workers=5)\n\n# Create tasks\ntask1 = Task(agent, "What\'s the weather in miami")\ntask2 = Task(agent, "What\'s the weather in new york")\ntask3 = Task(agent, "What\'s the weather in london")\n\n# Add tasks to the workflow\nworkflow.add(task1)\nworkflow.add(task2)\nworkflow.add(task3)\n\n# Run the workflow\nworkflow.run()\n\n```\n\n### `RecursiveWorkflow`\n- Recursively iterate on a workflow until a specific token is detected. \n\n```python\nimport os \nfrom dotenv import load_dotenv \nfrom swarms import OpenAIChat, Task, RecursiveWorkflow, Agent\n\n# Load environment variables from .env file\nload_dotenv()\n\n# Load environment variables\nllm = OpenAIChat(openai_api_key=os.getenv("OPENAI_API_KEY"))\nagent = Agent(llm=llm, max_loops=1)\n\n# Create a workflow\nworkflow = RecursiveWorkflow(stop_token="<DONE>")\n\n# Create tasks\ntask1 = Task(agent, "What\'s the weather in miami")\ntask2 = Task(agent, "What\'s the weather in new york")\ntask3 = Task(agent, "What\'s the weather in london")\n\n# Add tasks to the workflow\nworkflow.add(task1)\nworkflow.add(task2)\nworkflow.add(task3)\n\n# Run the workflow\nworkflow.run()\n\n\n```\n\n\n\n### `ModelParallelizer`\n- Concurrent Execution of Multiple Models: The ModelParallelizer allows you to run multiple models concurrently, comparing their outputs. This feature enables you to easily compare the performance and results of different models, helping you make informed decisions about which model to use for your specific task.\n\n- Plug-and-Play Integration: The structure provides a seamless integration with various models, including OpenAIChat, Anthropic, Mixtral, and Gemini. You can easily plug in any of these models and start using them without the need for extensive modifications or setup.\n\n\n```python\nimport os\n\nfrom dotenv import load_dotenv\n\nfrom swarms.models import Anthropic, Gemini, Mixtral, OpenAIChat\nfrom swarms.swarms import ModelParallelizer\n\nload_dotenv()\n\n# API Keys\nanthropic_api_key = os.getenv("ANTHROPIC_API_KEY")\nopenai_api_key = os.getenv("OPENAI_API_KEY")\ngemini_api_key = os.getenv("GEMINI_API_KEY")\n\n# Initialize the models\nllm = OpenAIChat(openai_api_key=openai_api_key)\nanthropic = Anthropic(anthropic_api_key=anthropic_api_key)\nmixtral = Mixtral()\ngemini = Gemini(gemini_api_key=gemini_api_key)\n\n# Initialize the parallelizer\nllms = [llm, anthropic, mixtral, gemini]\nparallelizer = ModelParallelizer(llms)\n\n# Set the task\ntask = "Generate a 10,000 word blog on health and wellness."\n\n# Run the task\nout = parallelizer.run(task)\n\n# Print the responses 1 by 1\nfor i in range(len(out)):\n    print(f"Response from LLM {i}: {out[i]}")\n```\n\n\n### Simple Conversational Agent\n- Plug in and play conversational agent with `GPT4`, `Mixytral`, or any of our models\n- Reliable conversational structure to hold messages together with dynamic handling for long context conversations and interactions with auto chunking\n- Reliable, this simple system will always provide responses you want.\n\n```python\nimport os\n\nfrom dotenv import load_dotenv\n\nfrom swarms import (\n    OpenAIChat,\n    Conversation,\n)\n\nconv = Conversation(\n    time_enabled=True,\n)\n\n# Load the environment variables\nload_dotenv()\n\n# Get the API key from the environment\napi_key = os.environ.get("OPENAI_API_KEY")\n\n# Initialize the language model\nllm = OpenAIChat(openai_api_key=api_key, model_name="gpt-4")\n\n# Run the language model in a loop\ndef interactive_conversation(llm):\n    conv = Conversation()\n    while True:\n        user_input = input("User: ")\n        conv.add("user", user_input)\n        if user_input.lower() == "quit":\n            break\n        task = (\n            conv.return_history_as_string()\n        )  # Get the conversation history\n        out = llm(task)\n        conv.add("assistant", out)\n        print(\n            f"Assistant: {out}",\n        )\n    conv.display_conversation()\n    conv.export_conversation("conversation.txt")\n\n\n# Replace with your LLM instance\ninteractive_conversation(llm)\n\n```\n\n\n### `SwarmNetwork`\n- Efficient Task Management: SwarmNetwork\'s intelligent agent pool and task queue management system ensures tasks are distributed evenly across agents. This leads to efficient use of resources and faster task completion.\n\n- Scalability: SwarmNetwork can dynamically scale the number of agents based on the number of pending tasks. This means it can handle an increase in workload by adding more agents, and conserve resources when the workload is low by reducing the number of agents.\n\n- Versatile Deployment Options: With SwarmNetwork, each agent can be run on its own thread, process, container, machine, or even cluster. This provides a high degree of flexibility and allows for deployment that best suits the user\'s needs and infrastructure.\n\n```python\nimport os\n\nfrom dotenv import load_dotenv\n\n# Import the OpenAIChat model and the Agent struct\nfrom swarms import OpenAIChat, Agent, SwarmNetwork\n\n# Load the environment variables\nload_dotenv()\n\n# Get the API key from the environment\napi_key = os.environ.get("OPENAI_API_KEY")\n\n# Initialize the language model\nllm = OpenAIChat(\n    temperature=0.5,\n    openai_api_key=api_key,\n)\n\n## Initialize the workflow\nagent = Agent(llm=llm, max_loops=1, agent_name="Social Media Manager")\nagent2 = Agent(llm=llm, max_loops=1, agent_name=" Product Manager")\nagent3 = Agent(llm=llm, max_loops=1, agent_name="SEO Manager")\n\n\n# Load the swarmnet with the agents\nswarmnet = SwarmNetwork(\n    agents=[agent, agent2, agent3],\n)\n\n# List the agents in the swarm network\nout = swarmnet.list_agents()\nprint(out)\n\n# Run the workflow on a task\nout = swarmnet.run_single_agent(\n    agent2.id, "Generate a 10,000 word blog on health and wellness."\n)\nprint(out)\n\n\n# Run all the agents in the swarm network on a task\nout = swarmnet.run_many_agents(\n    "Generate a 10,000 word blog on health and wellness."\n)\nprint(out)\n\n```\n\n\n### `Task`\nTask Execution: The Task structure allows for the execution of tasks by an assigned agent. The run method is used to execute the task. It\'s like a Zapier for LLMs\n\n- Task Description: Each Task can have a description, providing a human-readable explanation of what the task is intended to do.\n- Task Scheduling: Tasks can be scheduled for execution at a specific time using the schedule_time attribute.\n- Task Triggers: The set_trigger method allows for the setting of a trigger function that is executed before the task.\n- Task Actions: The set_action method allows for the setting of an action function that is executed after the task.\n- Task Conditions: The set_condition method allows for the setting of a condition function. The task will only be executed if this function returns True.\n- Task Dependencies: The add_dependency method allows for the addition of dependencies to the task. The task will only be executed if all its dependencies have been completed.\n- Task Priority: The set_priority method allows for the setting of the task\'s priority. Tasks with higher priority will be executed before tasks with lower priority.\n- Task History: The history attribute is a list that keeps track of all the results of the task execution. This can be useful for debugging and for tasks that need to be executed multiple times.\n\n```python\nfrom swarms.structs import Task, Agent\nfrom swarms.models import OpenAIChat\nfrom dotenv import load_dotenv\nimport os\n\n\n# Load the environment variables\nload_dotenv()\n\n\n# Define a function to be used as the action\ndef my_action():\n    print("Action executed")\n\n\n# Define a function to be used as the condition\ndef my_condition():\n    print("Condition checked")\n    return True\n\n\n# Create an agent\nagent = Agent(\n    llm=OpenAIChat(openai_api_key=os.environ["OPENAI_API_KEY"]),\n    max_loops=1,\n    dashboard=False,\n)\n\n# Create a task\ntask = Task(description="What\'s the weather in miami", agent=agent)\n\n# Set the action and condition\ntask.set_action(my_action)\ntask.set_condition(my_condition)\n\n# Execute the task\nprint("Executing task...")\ntask.run()\n\n# Check if the task is completed\nif task.is_completed():\n    print("Task completed")\nelse:\n    print("Task not completed")\n\n# Output the result of the task\nprint(f"Task result: {task.result}")\n\n\n```\n\n---\n\n\n## Real-World Deployment\n\n### Multi-Agent Swarm for Logistics\n- Swarms is a framework designed for real-world deployment here is a demo presenting a fully ready to use Swarm for a vast array of logistics tasks.\n- Swarms is designed to be modular and reliable for real-world deployments.\n- Swarms is the first framework that unleases multi-modal autonomous agents in the real world.\n\n```python\nfrom swarms.structs import Agent\nimport os\nfrom dotenv import load_dotenv\nfrom swarms.models import GPT4VisionAPI\nfrom swarms.prompts.logistics import (\n    Health_Security_Agent_Prompt,\n    Quality_Control_Agent_Prompt,\n    Productivity_Agent_Prompt,\n    Safety_Agent_Prompt,\n    Security_Agent_Prompt,\n    Sustainability_Agent_Prompt,\n    Efficiency_Agent_Prompt,\n)\n\n# Load ENV\nload_dotenv()\napi_key = os.getenv("OPENAI_API_KEY")\n\n# GPT4VisionAPI \nllm = GPT4VisionAPI(openai_api_key=api_key)\n\n# Image for analysis\nfactory_image = "factory_image1.jpg"\n\n# Initialize agents with respective prompts\nhealth_security_agent = Agent(\n    llm=llm,\n    sop=Health_Security_Agent_Prompt,\n    max_loops=1,\n    multi_modal=True,\n)\n\n# Quality control agent\nquality_control_agent = Agent(\n    llm=llm,\n    sop=Quality_Control_Agent_Prompt,\n    max_loops=1,\n    multi_modal=True,\n)\n\n\n# Productivity Agent\nproductivity_agent = Agent(\n    llm=llm,\n    sop=Productivity_Agent_Prompt,\n    max_loops=1,\n    multi_modal=True,\n)\n\n# Initiailize safety agent\nsafety_agent = Agent(\n    llm=llm, sop=Safety_Agent_Prompt, max_loops=1, multi_modal=True\n)\n\n# Init the security agent\nsecurity_agent = Agent(\n    llm=llm, sop=Security_Agent_Prompt, max_loops=1, multi_modal=True\n)\n\n\n# Initialize sustainability agent\nsustainability_agent = Agent(\n    llm=llm,\n    sop=Sustainability_Agent_Prompt,\n    max_loops=1,\n    multi_modal=True,\n)\n\n\n# Initialize efficincy agent\nefficiency_agent = Agent(\n    llm=llm,\n    sop=Efficiency_Agent_Prompt,\n    max_loops=1,\n    multi_modal=True,\n)\n\n# Run agents with respective tasks on the same image\nhealth_analysis = health_security_agent.run(\n    "Analyze the safety of this factory", factory_image\n)\nquality_analysis = quality_control_agent.run(\n    "Examine product quality in the factory", factory_image\n)\nproductivity_analysis = productivity_agent.run(\n    "Evaluate factory productivity", factory_image\n)\nsafety_analysis = safety_agent.run(\n    "Inspect the factory\'s adherence to safety standards",\n    factory_image,\n)\nsecurity_analysis = security_agent.run(\n    "Assess the factory\'s security measures and systems",\n    factory_image,\n)\nsustainability_analysis = sustainability_agent.run(\n    "Examine the factory\'s sustainability practices", factory_image\n)\nefficiency_analysis = efficiency_agent.run(\n    "Analyze the efficiency of the factory\'s manufacturing process",\n    factory_image,\n)\n```\n---\n\n\n## `Multi Modal Autonomous Agents`\n- Run the agent with multiple modalities useful for various real-world tasks in manufacturing, logistics, and health.\n\n```python\n# Description: This is an example of how to use the Agent class to run a multi-modal workflow\nimport os\nfrom dotenv import load_dotenv\nfrom swarms.models.gpt4_vision_api import GPT4VisionAPI\nfrom swarms.structs import Agent\n\n# Load the environment variables\nload_dotenv()\n\n# Get the API key from the environment\napi_key = os.environ.get("OPENAI_API_KEY")\n\n# Initialize the language model\nllm = GPT4VisionAPI(\n    openai_api_key=api_key,\n    max_tokens=500,\n)\n\n# Initialize the task\ntask = (\n    "Analyze this image of an assembly line and identify any issues such as"\n    " misaligned parts, defects, or deviations from the standard assembly"\n    " process. IF there is anything unsafe in the image, explain why it is"\n    " unsafe and how it could be improved."\n)\nimg = "assembly_line.jpg"\n\n## Initialize the workflow\nagent = Agent(\n    llm=llm,\n    max_loops="auto",\n    autosave=True,\n    dashboard=True,\n    multi_modal=True\n)\n\n# Run the workflow on a task\nagent.run(task=task, img=img)\n\n\n```\n\n---\n\n## Multi-Modal Model APIs\n\n### `Gemini`\n- Deploy Gemini from Google with utmost reliability with our visual chain of thought prompt that enables more reliable responses\n```python\nimport os\n\nfrom dotenv import load_dotenv\n\nfrom swarms.models import Gemini\nfrom swarms.prompts.visual_cot import VISUAL_CHAIN_OF_THOUGHT\n\n# Load the environment variables\nload_dotenv()\n\n# Get the API key from the environment\napi_key = os.environ.get("GEMINI_API_KEY")\n\n# Initialize the language model\nllm = Gemini(\n    gemini_api_key=api_key,\n    temperature=0.5,\n    max_tokens=1000,\n    system_prompt=VISUAL_CHAIN_OF_THOUGHT,\n)\n\n# Initialize the task\ntask = "This is an eye test. What do you see?"\nimg = "playground/demos/multi_modal_chain_of_thought/eyetest.jpg"\n\n# Run the workflow on a task\nout = llm.run(task=task, img=img)\nprint(out)\n```\n\n\n### `Anthropic`\n```python\n# Import necessary modules and classes\nfrom swarms.models import Anthropic\n\n# Initialize an instance of the Anthropic class\nmodel = Anthropic(\n    anthropic_api_key=""\n)\n\n# Using the run method\ncompletion_1 = model.run("What is the capital of France?")\nprint(completion_1)\n\n# Using the __call__ method\ncompletion_2 = model("How far is the moon from the earth?", stop=["miles", "km"])\nprint(completion_2)\n\n```\n\n\n### `HuggingFaceLLM`\n```python\nfrom swarms.models import HuggingfaceLLM\n\n# Initialize with custom configuration\ncustom_config = {\n    "quantize": True,\n    "quantization_config": {"load_in_4bit": True},\n    "verbose": True\n}\ninference = HuggingfaceLLM(model_id="NousResearch/Nous-Hermes-2-Vision-Alpha", **custom_config)\n\n# Generate text based on a prompt\nprompt_text = "Create a list of known biggest risks of structural collapse with references"\ngenerated_text = inference(prompt_text)\nprint(generated_text)\n```\n\n### `Mixtral`\n- Utilize Mixtral in a very simple API,\n- Utilize 4bit quantization for a increased speed and less memory usage\n- Use Flash Attention 2.0 for increased speed and less memory usage\n```python\nfrom swarms.models import Mixtral\n\n# Initialize the Mixtral model with 4 bit and flash attention!\nmixtral = Mixtral(load_in_4bit=True, use_flash_attention_2=True)\n\n# Generate text for a simple task\ngenerated_text = mixtral.run("Generate a creative story.")\n\n# Print the generated text\nprint(generated_text)\n```\n\n\n### `Dalle3`\n```python\nfrom swarms import Dalle3\n\n# Create an instance of the Dalle3 class with high quality\ndalle3 = Dalle3(quality="high")\n\n# Define a text prompt\ntask = "A high-quality image of a sunset"\n\n# Generate a high-quality image from the text prompt\nimage_url = dalle3(task)\n\n# Print the generated image URL\nprint(image_url)\n```\n\n\n### `GPT4Vision`\n```python\nfrom swarms.models import GPT4VisionAPI\n\n# Initialize with default API key and custom max_tokens\napi = GPT4VisionAPI(max_tokens=1000)\n\n# Define the task and image URL\ntask = "Describe the scene in the image."\nimg = "https://i.imgur.com/4P4ZRxU.jpeg"\n\n# Run the GPT-4 Vision model\nresponse = api.run(task, img)\n\n# Print the model\'s response\nprint(response)\n```\n\n\n### Text to Video with `ZeroscopeTTV`\n\n```python\n# Import the model\nfrom swarms import ZeroscopeTTV\n\n# Initialize the model\nzeroscope = ZeroscopeTTV()\n\n# Specify the task\ntask = "A person is walking on the street."\n\n# Generate the video!\nvideo_path = zeroscope(task)\nprint(video_path)\n\n```\n\n\n---\n\n# Features 🤖 \nThe Swarms framework is designed with a strong emphasis on reliability, performance, and production-grade readiness. \nBelow are the key features that make Swarms an ideal choice for enterprise-level AI deployments.\n\n## 🚀 Production-Grade Readiness\n- **Scalable Architecture**: Built to scale effortlessly with your growing business needs.\n- **Enterprise-Level Security**: Incorporates top-notch security features to safeguard your data and operations.\n- **Containerization and Microservices**: Easily deployable in containerized environments, supporting microservices architecture.\n\n## ⚙️ Reliability and Robustness\n- **Fault Tolerance**: Designed to handle failures gracefully, ensuring uninterrupted operations.\n- **Consistent Performance**: Maintains high performance even under heavy loads or complex computational demands.\n- **Automated Backup and Recovery**: Features automatic backup and recovery processes, reducing the risk of data loss.\n\n## 💡 Advanced AI Capabilities\n\nThe Swarms framework is equipped with a suite of advanced AI capabilities designed to cater to a wide range of applications and scenarios, ensuring versatility and cutting-edge performance.\n\n### Multi-Modal Autonomous Agents\n- **Versatile Model Support**: Seamlessly works with various AI models, including NLP, computer vision, and more, for comprehensive multi-modal capabilities.\n- **Context-Aware Processing**: Employs context-aware processing techniques to ensure relevant and accurate responses from agents.\n\n### Function Calling Models for API Execution\n- **Automated API Interactions**: Function calling models that can autonomously execute API calls, enabling seamless integration with external services and data sources.\n- **Dynamic Response Handling**: Capable of processing and adapting to responses from APIs for real-time decision making.\n\n### Varied Architectures of Swarms\n- **Flexible Configuration**: Supports multiple swarm architectures, from centralized to decentralized, for diverse application needs.\n- **Customizable Agent Roles**: Allows customization of agent roles and behaviors within the swarm to optimize performance and efficiency.\n\n### Generative Models\n- **Advanced Generative Capabilities**: Incorporates state-of-the-art generative models to create content, simulate scenarios, or predict outcomes.\n- **Creative Problem Solving**: Utilizes generative AI for innovative problem-solving approaches and idea generation.\n\n### Enhanced Decision-Making\n- **AI-Powered Decision Algorithms**: Employs advanced algorithms for swift and effective decision-making in complex scenarios.\n- **Risk Assessment and Management**: Capable of assessing risks and managing uncertain situations with AI-driven insights.\n\n### Real-Time Adaptation and Learning\n- **Continuous Learning**: Agents can continuously learn and adapt from new data, improving their performance and accuracy over time.\n- **Environment Adaptability**: Designed to adapt to different operational environments, enhancing robustness and reliability.\n\n\n## 🔄 Efficient Workflow Automation\n- **Streamlined Task Management**: Simplifies complex tasks with automated workflows, reducing manual intervention.\n- **Customizable Workflows**: Offers customizable workflow options to fit specific business needs and requirements.\n- **Real-Time Analytics and Reporting**: Provides real-time insights into agent performance and system health.\n\n## 🌐 Wide-Ranging Integration\n- **API-First Design**: Easily integrates with existing systems and third-party applications via robust APIs.\n- **Cloud Compatibility**: Fully compatible with major cloud platforms for flexible deployment options.\n- **Continuous Integration/Continuous Deployment (CI/CD)**: Supports CI/CD practices for seamless updates and deployment.\n\n## 📊 Performance Optimization\n- **Resource Management**: Efficiently manages computational resources for optimal performance.\n- **Load Balancing**: Automatically balances workloads to maintain system stability and responsiveness.\n- **Performance Monitoring Tools**: Includes comprehensive monitoring tools for tracking and optimizing performance.\n\n## 🛡️ Security and Compliance\n- **Data Encryption**: Implements end-to-end encryption for data at rest and in transit.\n- **Compliance Standards Adherence**: Adheres to major compliance standards ensuring legal and ethical usage.\n- **Regular Security Updates**: Regular updates to address emerging security threats and vulnerabilities.\n\n## 💬 Community and Support\n- **Extensive Documentation**: Detailed documentation for easy implementation and troubleshooting.\n- **Active Developer Community**: A vibrant community for sharing ideas, solutions, and best practices.\n- **Professional Support**: Access to professional support for enterprise-level assistance and guidance.\n\nSwarms framework is not just a tool but a robust, scalable, and secure partner in your AI journey, ready to tackle the challenges of modern AI applications in a business environment.\n\n\n## Documentation\n- Out documentation is located here at: [swarms.apac.ai](https://swarms.apac.ai)\n\n\n## 🫶 Contributions:\n\nSwarms is an open-source project, and contributions are welcome. If you want to contribute, you can create new features, fix bugs, or improve the infrastructure. Please refer to the [CONTRIBUTING.md](https://github.com/kyegomez/swarms/blob/master/CONTRIBUTING.md) and our [contributing board](https://github.com/users/kyegomez/projects/1) file in the repository for more information on how to contribute.\n\nTo see how to contribute, visit [Contribution guidelines](https://github.com/kyegomez/swarms/blob/master/CONTRIBUTING.md)\n\n<a href="https://github.com/kyegomez/swarms/graphs/contributors">\n  <img src="https://contrib.rocks/image?repo=kyegomez/swarms" />\n</a>\n\n\n## Community\n- [Join the Swarms community on Discord!](https://discord.gg/AJazBmhKnr)\n- Join our Swarms Community Gathering every Thursday at 1pm NYC Time to unlock the potential of autonomous agents in automating your daily tasks [Sign up here](https://lu.ma/5p2jnc2v)\n\n\n\n## Discovery Call\nBook a discovery call to learn how Swarms can lower your operating costs by 40% with swarms of autonomous agents in lightspeed. [Click here to book a time that works for you!](https://calendly.com/swarm-corp/30min?month=2023-11)\n\n# License\nApache License\n',
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/kyegomez/swarms',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
